@@ -6,7 +6,10 @@ Functions associated with mrks inversion
 
 import numpy as np
 from opt_einsum import contract
-import psi4
+try: 
+    import psi4
+except:
+    pass
 import time
 
 class MRKS():
@@ -440,12 +443,12 @@ class MRKS():
             C_a_NO = Ca @ C_a_NO
 
             # prepare properties on the grid
-            ebarWF = self._average_local_orbital_energy(self.nt[0], C_a_GFM, eigs_a_GFM)
-            taup_rho_WF = self._pauli_kinetic_energy_density(self.nt[0], C_a_NO, eigs_a_NO)
+            ebarWF = self._average_local_orbital_energy(self.Dt[0], C_a_GFM, eigs_a_GFM)
+            taup_rho_WF = self._pauli_kinetic_energy_density(self.Dt[0], C_a_NO, eigs_a_NO)
         elif self.wfn.name() == "RHF":  # Since HF is a special case, no need for GFM and NO as in CI.
             epsilon_a = self.wfn.epsilon_a_subset("AO", "OCC").np
-            ebarWF = self._average_local_orbital_energy(self.nt[0], self.ct[0][:,:Nalpha], epsilon_a)
-            taup_rho_WF = self._pauli_kinetic_energy_density(self.nt[0], self.ct[0])
+            ebarWF = self._average_local_orbital_energy(self.Dt[0], self.ct[0][:,:Nalpha], epsilon_a)
+            taup_rho_WF = self._pauli_kinetic_energy_density(self.Dt[0], self.ct[0])
         else:
             raise ValueError("Currently only supports Spin-Restricted "
                              "calculations since Spin-Unrestricted CI "
@@ -457,7 +460,7 @@ class MRKS():
 
         # Initialization.
         if init is None:
-            self.Da = np.copy(self.nt[0])
+            self.Da = np.copy(self.Dt[0])
             self.Coca = np.copy(self.ct[0])
             self.eigvecs_a = self.wfn.epsilon_a().np[:Nalpha]
         elif init.lower()=="continue":
@@ -509,7 +512,7 @@ class MRKS():
             self._diagonalize_with_potential_vFock(v=vxc_Fock)
 
             print(f"Iter: {mRKS_step}, Density Change: {Derror:2.2e}, Eigenvalue Change: {eerror:2.2e}, "
-                  "Potential Change: {verror:2.2e}.")
+                  f"Potential Change: {verror:2.2e}.")
 
         if vxc_grid is not None:
             grid_info = self.grid_to_blocks(vxc_grid)
@@ -519,18 +522,18 @@ class MRKS():
             vxchole = self._vxc_hole_quadrature(grid_info=grid_info,
                                                 atol=sing[2], atol1=sing[3])
             if self.wfn.name() == "CIWavefunction":
-                ebarWF = self._average_local_orbital_energy(self.nt[0],
+                ebarWF = self._average_local_orbital_energy(self.Dt[0],
                                                             C_a_GFM, eigs_a_GFM,
                                                             grid_info=grid_info)
-                taup_rho_WF = self._pauli_kinetic_energy_density(self.nt[0],
+                taup_rho_WF = self._pauli_kinetic_energy_density(self.Dt[0],
                                                                  C_a_NO, eigs_a_NO,
                                                                  grid_info=grid_info)
             elif self.wfn.name() == "RHF":
-                ebarWF = self._average_local_orbital_energy(self.nt[0],
+                ebarWF = self._average_local_orbital_energy(self.Dt[0],
                                                             self.ct[0],
                                                             epsilon_a[:Nalpha],
                                                             grid_info=grid_info)
-                taup_rho_WF = self._pauli_kinetic_energy_density(self.nt[0],
+                taup_rho_WF = self._pauli_kinetic_energy_density(self.Dt[0],
                                                                  self.ct[0],
                                                                  grid_info=grid_info)
             ebarKS = self._average_local_orbital_energy(self.Da, self.Coca,
